package cn.timer.api.controller.insure;

import cn.timer.api.bean.insure.CallBack;
import cn.timer.api.bean.insure.InsureLog;
import cn.timer.api.bean.insure.InsurePolicy;
import cn.timer.api.bean.insure.InsureUser;
import cn.timer.api.bean.yggl.YgglMainEmp;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.google.common.collect.Maps;
import com.mysql.cj.util.StringUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.codec.digest.DigestUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.io.InputStream;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description TODO
 * @Author wgd
 * @Date 2022/3/3 8:45
 */
@Api(tags = "8.0回调接口")
@RestController
@Transactional
@RequestMapping(value = "/callBack/policy", produces = {"application/json"})
public class CallBackContorll {
    private static final Logger log = LoggerFactory.getLogger(CallBackContorll.class);
    /*保全测试用*/
    @Value("${insure.appidq}")
    private String appidq;
    @Value("${insure.secretq}")
    private String secretq;

    @Value("${BASE_API_URL}")
    private String base_api_url;

    @PostMapping(value = "/insuredCallBack")
    @ApiOperation(value = "6.投保申请回调", httpMethod = "POST", notes = "投保申请回调")
    @ApiOperationSupport(order = 2)
    private Map insuredCallBack(HttpServletRequest request, @RequestParam String pid, @RequestParam String sign, @RequestParam String timestamp) throws IOException {
        Map map = Maps.newHashMap();
        map.put("status", "error");
        if (StringUtils.isNullOrEmpty(pid) || StringUtils.isNullOrEmpty(sign) && StringUtils.isNullOrEmpty(timestamp)) {
            return map;
        }
        if (!pid.equals(appidq)) {
            return map;
        }
        InputStream is = null;
        is = request.getInputStream();
        StringBuilder sb = new StringBuilder();
        byte[] b = new byte[4096];
        for (int n; (n = is.read(b)) != -1; ) {
            sb.append(new String(b, 0, n));
        }
        String value = DigestUtils.md5Hex(appidq + secretq + timestamp + sb.toString());
        if (!value.equals(sign)) {
            return map;
        }
        CallBack callBack = JSONObject.parseObject(sb.toString(), CallBack.class);
        Map trueMap = Maps.newHashMap();
        trueMap.put("status", "1");
        return trueMap;
    }

    @PostMapping(value = "/CallBack")
    @ApiOperation(value = "7.保全增员申请回调", httpMethod = "POST", notes = "投保申请回调")
    @ApiOperationSupport(order = 2)
    private Map callBack(HttpServletRequest request, @RequestParam String pid, @RequestParam String sign, @RequestParam String timestamp) throws IOException {
        Map map = Maps.newHashMap();
        map.put("status", "error");
        if (StringUtils.isNullOrEmpty(pid) || StringUtils.isNullOrEmpty(sign) && StringUtils.isNullOrEmpty(timestamp)) {
            return map;
        }
        if (!pid.equals(appidq)) {
            return map;
        }
        InputStream is = null;
        is = request.getInputStream();
        StringBuilder sb = new StringBuilder();
        byte[] b = new byte[4096];
        for (int n; (n = is.read(b)) != -1; ) {
            sb.append(new String(b, 0, n));
        }
        String value = DigestUtils.md5Hex(appidq + secretq + timestamp + sb.toString());
        if (!value.equals(sign)) {
            return map;
        }
        Map paramsMap = Maps.newHashMap();
        paramsMap.put("pid", pid);
        paramsMap.put("timestamp", timestamp);
        paramsMap.put("sign", sign);
        CallBack callBack = JSONObject.parseObject(sb.toString(), CallBack.class);
        log.info("callBack=====" + sb.toString());
        if (callBack.getStatus().equals("1")) {
            List<InsureUser> list = InsureUser.builder().build().selectList(new QueryWrapper<InsureUser>().lambda().eq(InsureUser::getBatchNo, callBack.getOrder_import_info().getUuid()).eq(InsureUser::getInsureStatus, 3));
            list.forEach(i -> {
                i.setInsureStatus(1);
                i.updateById();
                YgglMainEmp.builder().isInsure(1).build().update(new QueryWrapper<YgglMainEmp>().lambda().eq(YgglMainEmp::getId, i.getUserId()));
            });
            List<InsureUser> oldlist = InsureUser.builder().build().selectList(new QueryWrapper<InsureUser>().lambda().eq(InsureUser::getReplaceTransId, callBack.getOrder_import_info().getUuid()));
            if (oldlist != null && oldlist.size() > 0) {
                oldlist.forEach(i -> {
                    i.setInsureStatus(4);
                    i.setStatus("2");
                    i.updateById();
                    YgglMainEmp.builder().isInsure(0).build().update(new QueryWrapper<YgglMainEmp>().lambda().eq(YgglMainEmp::getId, i.getUserId()));
                });
            }
            InsurePolicy insurePolicy = InsurePolicy.builder().build().selectOne(new QueryWrapper<InsurePolicy>().lambda().eq(InsurePolicy::getPolicyNo, list.get(0).getPolicyNo()));
            if (oldlist == null || oldlist.size() == 0) {
                insurePolicy.setTotalPremium(String.valueOf(Double.valueOf(insurePolicy.getTotalPremium()) + Double.valueOf(callBack.getOrder_import_info().getTotal_money())));
            }
            insurePolicy.setPolicyFile(callBack.getOrder_import_info().getEndorsement_file());
            insurePolicy.setUpdateTime(new Date());
            insurePolicy.updateById();
            InsureLog.builder().requestParam(JSONObject.toJSONString(paramsMap)).type(7)
                    .requestData(sb.toString()).createTime(new Date()).requestType(1).returnBody(JSONObject.toJSONString(callBack)).requestPath(base_api_url + "/callBack/policy/CallBack")
                    .returnCode(callBack.getStatus()).returnMsg("更新成功").policyId(insurePolicy.getId()).build().insert();
        } else {
            String errorMsg = "";
            InsureLog insureLog = InsureLog.builder().build().selectOne(new QueryWrapper<InsureLog>().lambda().eq(InsureLog::getTransId, callBack.getOrder_import_info().getThird_uuid()));
            List<Map> errMap = callBack.getOrder_import_info().getErr_list();
            if (errMap.size() > 0) {
                for (int i = 0; i < errMap.size(); i++) {
                    errorMsg = errorMsg + ("姓名："+errMap.get(i).get("name").toString()+"，错误："+errMap.get(i).get("err_content").toString() + ',');
                }
            } else {
                errorMsg = callBack.getErr_msg();
            }
            //TODO 写入日志
            InsureLog.builder().requestParam(JSONObject.toJSONString(paramsMap)).type(7)
                    .requestData(sb.toString()).createTime(new Date()).requestType(1).returnBody(JSONObject.toJSONString(callBack)).requestPath(base_api_url + "/callBack/policy/CallBack")
                    .returnCode(callBack.getStatus()).returnMsg(errorMsg).policyId(insureLog.getPolicyId()).build().insert();
        }
        Map trueMap = Maps.newHashMap();
        trueMap.put("status", "1");

        return trueMap;
    }
}
