package cn.timer.api.controller.zpgl;

import cn.timer.api.bean.zpgl.ZpglFail;
import cn.timer.api.config.annotation.CurrentUser;
import cn.timer.api.config.annotation.UserBean;
import cn.timer.api.config.exception.CustomException;
import cn.timer.api.utils.Result;
import cn.timer.api.utils.ResultUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;

import javax.transaction.Transactional;
import java.util.List;

/**
 * 招聘管理
 *
 * @author wuqingjun
 * @email 284718418@qq.com
 * @date 2022-03-08 15:14:40
 */
@Api(tags = "招聘管理")
@Transactional(rollbackOn = Exception.class)
@RestController
@RequestMapping(value = "/zpgl", produces = {"application/json"})
public class ZpglFailController {

    /**
     * 招聘-淘汰原因字典
     *
     * @param
     * @return
     */
    @GetMapping(value = "/fail")
    @ApiOperation(value = "1.淘汰原因字典", httpMethod = "GET", notes = "淘汰原因字典")
    @ApiOperationSupport(order = 1)
    public Result<Object> fail(@CurrentUser UserBean userBean, @ApiParam("招聘状态") @RequestParam(required = false) Integer status) {
        try {
            QueryWrapper<ZpglFail> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().eq(ZpglFail::getDeleteFlag, 0).eq(ZpglFail::getOrgCode, userBean.getOrgCode()).eq(ZpglFail::getZpglRcxxStatus, status);
            List<ZpglFail> zpglFail = ZpglFail.builder().build().selectList(queryWrapper);
            return ResultUtil.data(zpglFail, "查询成功");
        } catch (Exception e) {
            e.printStackTrace();
            throw new CustomException("招聘-淘汰原因字典失败");
        }
    }

    /**
     * 招聘-添加淘汰原因
     *
     * @param
     * @return
     */
    @PostMapping(value = "/save")
    @ApiOperation(value = "2.招聘-添加淘汰原因", httpMethod = "POST", notes = "招聘-添加淘汰原因")
    @ApiOperationSupport(order = 2)
    public Result<Object> save(@CurrentUser UserBean userBean, @RequestBody ZpglFail zpglFail) {
        try {
            zpglFail.setCreateUserId(userBean.getEmpNum());
            zpglFail.setUpdateUserId(userBean.getEmpNum());
            zpglFail.setOrgCode(userBean.getOrgCode());
            return zpglFail.insert() ? ResultUtil.success() : ResultUtil.error();
        } catch (Exception e) {
            e.printStackTrace();
            throw new CustomException("招聘-添加淘汰原因失败");
        }
    }

}
